@@ -25,12 +25,11 @@
 #define BITMASK_UNSET(x, mask) ((x) & BITWISE_NOT(mask))
 #define BITMASK_SET(x, mask) ((x) | (mask))
 
-static void __attribute__((noreturn))
+static void KBD_ATTR_NORETURN
 usage(int rc, const struct kbd_help *options)
 {
-	const struct kbd_help *h;
 	fprintf(stderr, _("Usage: %s [option...] [[+|-][ num | caps | scroll %s]]\n"),
-			get_progname(),
+			program_invocation_short_name,
 #ifdef __sparc__
 	        "| compose "
 #else
@@ -49,27 +48,8 @@ usage(int rc, const struct kbd_help *options)
 	                  "With -D, setleds sets both the flags and the default flags, so\n"
 	                  "that a subsequent reset will not change the flags.\n"));
 
-	if (options) {
-		int max = 0;
-
-		fprintf(stderr, "\n");
-		fprintf(stderr, _("Options:"));
-		fprintf(stderr, "\n");
-
-		for (h = options; h && h->opts; h++) {
-			int len = (int) strlen(h->opts);
-			if (max < len)
-				max = len;
-		}
-		max += 2;
-
-		for (h = options; h && h->opts; h++)
-			fprintf(stderr, "  %-*s %s\n", max, h->opts, h->desc);
-	}
-
-	fprintf(stderr, "\n");
-	fprintf(stderr, _("Report bugs to authors.\n"));
-	fprintf(stderr, "\n");
+	print_options(options);
+	print_report_bugs();
 
 	exit(rc);
 }
@@ -101,7 +81,7 @@ report(int leds)
 	       onoff(leds & LED_SCR));
 }
 
-struct led {
+static struct led {
 	const char *name;
 	unsigned char bit;
 	unsigned char sunbit;
@@ -143,14 +123,8 @@ getflags(unsigned char *flags)
 
 static int sunkbdfd = -1;
 
-#ifndef KIOCGLED
-#define arg_state __attribute__((unused))
-#else
-#define arg_state
-#endif
-
 static void
-sungetleds(arg_state unsigned char *cur_leds)
+sungetleds(unsigned char *cur_leds KBD_ATTR_UNUSED)
 {
 #ifdef KIOCGLED
 	if (ioctl(sunkbdfd, KIOCGLED, cur_leds)) {
@@ -162,14 +136,8 @@ sungetleds(arg_state unsigned char *cur_leds)
 #endif
 }
 
-#ifndef KIOCSLED
-#define arg_state __attribute__((unused))
-#else
-#define arg_state
-#endif
-
 static void
-sunsetleds(arg_state unsigned char *cur_leds)
+sunsetleds(unsigned char *cur_leds KBD_ATTR_UNUSED)
 {
 #ifdef KIOCSLED
 	if (ioctl(sunkbdfd, KIOCSLED, cur_leds)) {
@@ -228,7 +196,6 @@ int main(int argc, char **argv)
 	unsigned char nval, ndef;
 	unsigned char osunleds = 0, nsunleds, nsunval, nsundef;
 
-	set_progname(argv[0]);
 	setuplocale();
 
 	const struct kbd_option opts[] = {
