@@ -7,10 +7,8 @@
 #include "libcommon.h"
 
 int
-main(int __attribute__((unused)) argc, char **argv)
+main(int argc KBD_ATTR_UNUSED, char **argv KBD_ATTR_UNUSED)
 {
-	set_progname(argv[0]);
-
 	struct lk_ctx *ctx;
 
 	if ((ctx = lk_init()) == NULL)
